==> ctpp2-2.6.8.tar.gz: ctpp2-2.6.8/include/functions/FnGetText_.hpp <==
/*-
 * Copyright (c) 2004 - 2011 CTPP Team
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the CTPP Team nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *      FnGetText_.hpp
 *
 * $CTPP$
 */
#ifndef _FN_GET_TEXT__HPP__
#define _FN_GET_TEXT__HPP__ 1

#include "CTPP2VMSyscall.hpp"

/**
  @file FnGetText_.hpp
  @brief Virtual machine standard library function, localization support
*/

namespace CTPP // C++ Template Engine
{

class CDT;
class Logger;

/**
  @class FnGetText_ FnGetText_.hpp <FnGetText_.hpp>
  @brief Localization support
*/
class FnGetText_:
  public SyscallHandler
{
	/**
	  @brief Constructor
	*/
 	FnGetText_();

	/**
	  @brief A destructor
	*/
	~FnGetText_() throw();

private:
	friend class STDLibInitializer;

	/**
	  @brief Handler
	  @param aArguments - list of arguments
	  @param iArgNum - number of arguments
	  @param oCDTRetVal - return value
	  @param oLogger - logger
	  @return 0 - if success, -1 - otherwise
	*/
	INT_32 Handler(CDT            * aArguments,
	               const UINT_32    iArgNum,
	               CDT            & oCDTRetVal,
	               Logger         & oLogger);

	/**
	  @brief Get function name
	*/
	CCHAR_P GetName() const;
};

} // namespace CTPP
#endif // _FN_GET_TEXT__HPP__
// End.

==> ctpp2-2.8.1.tar.gz: ctpp2-2.8.1/include/functions/FnGetText_.hpp <==
/*-
 * Copyright (c) 2004 - 2011 CTPP Team
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the CTPP Team nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *      FnGetText.hpp
 *
 * $CTPP$
 */
#ifndef _FN_GET_TEXT__HPP__
#define _FN_GET_TEXT__HPP__ 1

#include "CTPP2VMSyscall.hpp"

/**
  @file FnGetText_.hpp
  @brief Virtual machine standard library function, localization support
*/

namespace CTPP // C++ Template Engine
{

class CDT;
class Logger;
class CTPP2GetText;

/**
  @class FnGetText_ FnGetText_.hpp <FnGetText.hpp>
  @brief Localization support
*/
class FnGetText_:
  public SyscallHandler
{
	/**
	  @brief Constructor
	*/
	FnGetText_();

	/**
	  @brief A destructor
	*/
	~FnGetText_() throw();

private:
	friend class STDLibInitializer;
	friend class CTPP2GetText;

	/**
	  @brief Handler
	  @param aArguments - list of arguments
	  @param iArgNum - number of arguments
	  @param oCDTRetVal - return value
	  @param oLogger - logger
	  @return 0 - if success, -1 - otherwise
	*/
	INT_32 Handler(CDT            * aArguments,
	               const UINT_32    iArgNum,
	               CDT            & oCDTRetVal,
	               Logger         & oLogger);

	/**
	  @brief Get function name
	*/
	CCHAR_P GetName() const;

	/**
	  @brief Set GetText object
	  @param gettext - GetText object
	*/
	void SetGetText(CTPP2GetText * pGetText);

	/**
	  @brief Set language of translation
	  @param sLang - language
	*/
	void SetLanguage(const STLW::string & sLang);

	/** GetText pointer         */
	CTPP2GetText * pGetText;

	/** Language of translation */
	STLW::string sLanguage;
};

} // namespace CTPP
#endif // _FN_GET_TEXT_HPP__
// End.
